@@ -1,17 +1,19 @@
 package Class::PObject;
 
-# $Id: PObject.pm,v 1.43 2003/09/09 08:46:33 sherzodr Exp $
+# $Id: PObject.pm,v 1.54.2.3 2004/05/20 06:59:14 sherzodr Exp $
 
 use strict;
 #use diagnostics;
 use Log::Agent;
 use vars ('$VERSION', '$revision');
 
-$VERSION    = '2.07_01';
-($revision) = '$Revision: 1.43 $' =~ m/Revision:\s*(\S+)/;
+$VERSION  = '2.15_01';
+$revision = '$Revision: 1.54.2.3 $';
 
 # configuring Log::Agent
-logconfig(-level=>$ENV{POBJECT_DEBUG} || 0);
+logconfig(-level=>$ENV{POBJECT_DEBUG} || 0, 
+          -prefix=>'***',
+          -caller => [-format => '%-30s->', -info   => "sub"]);
 
 sub import {
     my $class       = shift;
@@ -77,7 +79,10 @@ sub pobject {
     }
 
     # certain method names are reserved. Making sure they won't get overridden
-    my @reserved_methods = qw(new load fetch save pobject_init set get DESTROY);
+    my @reserved_methods = qw(
+        new load fetch save remove remove_all set get
+        pobject_init drop_datasource init_datasource DESTROY
+    );
     for my $method ( @reserved_methods ) {
         for my $column ( @{$props->{columns}} ) {
             if ( $method eq $column ) {
@@ -98,6 +103,9 @@ sub pobject {
     # if no driver was specified, default driver to be used is 'file'
     $props->{driver} ||= 'file';
 
+    # if no serializer set defaulting to 'storable'
+    $props->{serializer} ||= 'storable';
+
     # it's important that we cache all the properties passed to the pobject()
     # as a static data. This lets multiple instances of the pobject to access
     # this data whenever needed
@@ -108,23 +116,7 @@ sub pobject {
     # objects, let's also set the caller's @ISA array:
     push @{ "$class\::ISA" }, "Class::PObject::Template";
 
-    ####
-    # After dealing with ISA, I don't think the following would be
-    # necessary.
-
-    #*{ "$class\::new" }         = \&Class::PObject::Template::new;
-    #*{ "$class\::columns" }     = \&Class::PObject::Template::columns;
-    #*{ "$class\::load" }        = \&Class::PObject::Template::load;
-    #*{ "$class\::fetch" }       = \&Class::PObject::Template::fetch;
-    #*{ "$class\::save" }        = \&Class::PObject::Template::save;
-    #*{ "$class\::remove" }      = \&Class::PObject::Template::remove;
-    #*{ "$class\::remove_all" }  = \&Class::PObject::Template::remove_all;
-    #*{ "$class\::count" }       = \&Class::PObject::Template::count;
-    #*{ "$class\::errstr" }      = \&Class::PObject::Template::errstr;
-    #*{ "$class\::dump" }        = \&Class::PObject::Template::dump;
-    #*{ "$class\::__props" }     = \&Class::PObject::Template::__props;
-    #*{ "$class\::__driver" }    = \&Class::PObject::Template::__driver;
-
+    # creating accessor methods
     for my $colname ( @{ $props->{columns} } ) {
         if ( $class->UNIVERSAL::can($colname) ) {
             logcarp "method '%s' exists in the caller's package", $colname;
@@ -139,7 +131,6 @@ sub pobject {
             return $get->( $_[0], $colname )
         }
     }
-
 }
 
 logtrc 1, "%s loaded successfully", __PACKAGE__;
@@ -429,7 +420,7 @@ if result set consists of a single object.
 =head2 LOADING OBJECTS SELECTIVELY
 
 Sometimes you just want to load objects matching a specific criteria, say, you want all the people
-whose name are I<John>. You can achieve this by passing a hashref as the first argument to C<load()>:
+whose name are I<John>. You can achieve this by passing a hash ref as the first argument to C<load()>:
 
     @johns = Person->load({name=>"John"});
 
@@ -438,7 +429,7 @@ Sets of key/value pairs passed to C<load()> as the first argument are called I<t
 You can also apply post-result filtering to your list, such as sorting by a specific column
 in a specific order, and limit the list to I<n> number of objects and start the listing at
 object I<n> of the result set. All these attributes can be passed as the second argument to
-C<load()> in the form of a hashref and are called I<arguments> :
+C<load()> in the form of a has href and are called I<arguments> :
 
     @people = Person->load(undef, {sort=>'name', direction=>'desc', limit=>100});
 
@@ -669,9 +660,9 @@ allows it to be used in similar way as I<ENCRYPT> column type.
 =back
 
 Up to this point you noticed that objects' accessor methods have been returning
-strings, right? Wrong! They have been returning objects of their appropriate types.
-But you didn't notice them and kept treating them as strings because of smart
-operator overloading feature of those objects.
+strings, right? Wrong! They have been returning objects of their appropriate types (CHAR, 
+VARCHAR, ENCRYPT and etc.). But you didn't notice them and kept treating them as strings 
+because of smart operator overloading feature of those objects.
 
 This means, if at any time in your program you want to discover the type of a specific
 column, you could simply use Perl's built-in I<ref()> function:
@@ -679,6 +670,30 @@ column, you could simply use Perl's built-in I<ref()> function:
     print ref( $user->psswd), "\n"; # <-- prints ENCRYPT
     print ref( $user->name ), "\n"; # <-- print VARCHAR
 
+=head2 COLUMN MEMBER FUNCTIONS
+
+Objects returned by calling accessor methods support several built-in methods, also
+known as I<member functions>. These member functions are usually meant to manipulate
+the value of the column before returning to the caller, but are not meant to modify 
+the actual value of the column. So you can fearlessly call any of the member functions
+without modifying their values in the object.
+
+Although L<Typemap Specifications|Class::PObject::Types> and respective type classes cover
+all the necessary details about each of these member functions, in this section we'll just cover
+C<uc> as an example, which returns the upper-cased version of the string:
+
+    $user = User->load( $user_id );
+    printf( "Hello %s!\n", $user->name()->uc() );
+
+Assuming value of C<< $user->name() >> was I<Sherzod>, C<< $user->name()->uc() >> returns
+I<SHERZOD> by uppercasing all the characters of the word.
+
+After C<< $user->name()->uc() >> is called, C<< $user->name() >> keeps returning I<Sherzod>. 
+As we mentioned early initial value of the column would not be altered.
+
+See L<Typemap Specifications|Class::PObject::Types> and respective type classes for
+the list of all the available member functions available for all and specific column types.
+
 =head2 DEFINING METHODS OTHER THAN ACCESSORS
 
 In some cases accessor methods are not all the methods your class may ever need. It may
@@ -860,7 +875,7 @@ This error message is also available through C<$CLASS::errstr> global variable:
 =item *
 
 C<__props()> - returns I<class properties>. Class properties are usually whatever was
-passed to C<pobject()> as a hashref, either as the first argument or the second.
+passed to C<pobject()> as a has href, either as the first argument or the second.
 This information is usually helpful for driver authors, and for those who want to access
 certain information about this class.
 
@@ -982,6 +997,17 @@ to DBM
 You can learn more about column type specs from L<Class::PObject::Type|Class::PObject::Type>,
 which is also a base class of all the types.
 
+=head1 KNOWN BUGS AND ISSUES
+
+=head2 ithreads
+
+On platforms where Perl was built I<ithreads> enabled, several tests during I<make test> may
+fail. Although these particular failures are found to be related to a bug in L<Test::Builder|Test::Builder>, 
+it's still not clear whether Class::PObject is fully compatible with I<ithreads> or not. Volunteers
+are welcome to help us find out.
+
+For more details of these problems refer to http://rt.cpan.org/NoAuth/Bug.html?id=4218
+
 =head1 SEE ALSO
 
 http://poop.sourceforge.net/, although little dated, provides brief overview
@@ -999,6 +1025,6 @@ Copyright (c) 2003 Sherzod B. Ruzmetov. All rights reserved.
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
-$Date: 2003/09/09 08:46:33 $
+$Date: 2004/05/20 06:59:14 $
 
 =cut
