@@ -1,6 +1,6 @@
 package Class::PObject::Driver::DBI;
 
-# $Id: DBI.pm,v 1.11 2003/09/09 08:46:36 sherzodr Exp $
+# $Id: DBI.pm,v 1.13 2003/11/07 04:51:04 sherzodr Exp $
 
 use strict;
 #use diagnostics;
@@ -11,8 +11,7 @@ use vars ('$VERSION', '@ISA');
 
 @ISA = ('Class::PObject::Driver');
 
-$VERSION = '2.01';
-
+$VERSION = '2.02';
 
 
 
@@ -34,9 +33,9 @@ sub _prepare_create_table {
             }
         }
         if ( $column eq 'id' ) {
-            push @cols, "id INTEGER PRIMARY KEY";
+            push @cols, "id INTEGER PRIMARY KEY NOT NULL";
         } else {
-            push @cols, sprintf "%s %s", $column, $type;
+            push @cols, sprintf "%s %s NULL", $column, $type;
         }
     }
     my $sql =  sprintf "\nCREATE TABLE %s (\n\t%s\n)", $tablename, join ",\n\t", @cols;
@@ -46,9 +45,6 @@ sub _prepare_create_table {
 
 
 
-
-
-
 sub _prepare_where_clause {
     my ($self, $terms) = @_;
 
@@ -92,7 +88,6 @@ sub _prepare_select {
 
 
 
-
 sub _prepare_delete {
     my ($self, $table_name, $terms) = @_;
 
@@ -107,7 +102,6 @@ sub _prepare_delete {
 
 
 
-
 sub _prepare_insert {
     my ($self, $table_name, $columns) = @_;
 
@@ -126,8 +120,6 @@ sub _prepare_insert {
 
 
 
-
-
 sub _prepare_update {
     my ($self, $table_name, $columns, $terms) = @_;
 
@@ -149,10 +141,6 @@ sub _prepare_update {
 
 
 
-
-
-
-
 sub _tablename {
     my ($self, $object_name, $props, $dbh) = @_;
 
@@ -168,7 +156,6 @@ sub _tablename {
 
 
 
-
 sub load {
     my $self = shift;
     my ($object_name, $props, $id) = @_;
@@ -188,10 +175,6 @@ sub load {
 
 
 
-
-
-
-
 sub load_ids {
     my $self = shift;
     my ($object_name, $props, $terms, $args) = @_;
@@ -221,10 +204,6 @@ sub load_ids {
 
 
 
-
-
-
-
 sub remove {
     my $self = shift;
     my ($object_name, $props, $id)  = @_;
@@ -248,8 +227,6 @@ sub remove {
 
 
 
-
-
 sub remove_all {
     my $self  = shift;
     my ($object_name, $props, $terms) = @_;
@@ -267,6 +244,7 @@ sub remove_all {
 }
 
 
+
 sub drop_datasource {
     my $self = shift;
     my ($object_name, $props) = @_;
@@ -283,9 +261,6 @@ sub drop_datasource {
 
 
 
-
-
-
 sub count {
     my $self = shift;
     my ($object_name, $props, $terms) = @_;
@@ -307,9 +282,6 @@ sub count {
 
 
 
-
-
-
 sub _read_lock {
     my ($self, $dbh, $table) = @_;
 
@@ -322,10 +294,6 @@ sub _read_lock {
 
 
 
-
-
-
-
 sub _write_lock {
     my ($self, $dbh, $table) = @_;
 
@@ -338,8 +306,6 @@ sub _write_lock {
 
 
 
-
-
 sub _unlock {
     my ($self, $dbh, $table) = @_;
 
