@@ -1,6 +1,6 @@
 package Class::PObject::Driver::file;
 
-# $Id: file.pm,v 1.15.2.2 2003/09/06 10:14:57 sherzodr Exp $
+# $Id: file.pm,v 1.18 2003/09/09 08:46:36 sherzodr Exp $
 
 use strict;
 #use diagnostics;
@@ -202,6 +202,29 @@ sub remove {
 
 
 
+
+
+
+sub drop_datasource {
+    my ($self, $object_name, $props, $i) = @_;
+
+
+    my $dir = $self->_dir($object_name, $props);
+    logtrc 3, "removing '%s'", $dir;
+    require File::Path;
+    unless ( File::Path::rmtree($dir) ) {
+        $self->errstr( "couldn't unlink '%s': %s", $dir, $!);
+        return undef
+    }
+    return 1
+}
+
+
+
+
+
+
+
 sub generate_id {
     my ($self, $object_name, $props) = @_;
 
@@ -240,7 +263,7 @@ sub generate_id {
 sub _filename {
     my ($self, $object_name, $props, $id) = @_;
 
-    unless ( $object_name && $id ) {
+    unless ( $object_name && defined($id) ) {
         logcroak "Usage: _filename(\$id)";
     }
     my $dir = $self->_dir($object_name, $props) or return;
