@@ -1,19 +1,19 @@
 package Class::PObject::Template;
 
-# $Id: Template.pm,v 1.21 2003/09/09 08:46:35 sherzodr Exp $
+# $Id: Template.pm,v 1.22.2.2 2004/05/20 06:53:53 sherzodr Exp $
 
 use strict;
 #use diagnostics;
 use Log::Agent;
+use Data::Dumper;
 use Carp;
 use vars ('$VERSION');
 use overload (
     '""'    => sub { $_[0]->id },
-    #bool    => sub { $_[0]->id  },
     fallback=> 1
 );
 
-$VERSION = '1.90';
+$VERSION = '1.91';
 
 sub new {
     my $class = shift;
@@ -69,11 +69,13 @@ sub set {
     unless ( @_ == 2  ) {
         logcroak "%s->set() usage error", ref($self)
     }
+
+#    print Dumper($self->{columns});
     #return $self->{columns}->{$colname} = ref($colvalue) ? $colvalue->id : $colvalue;
 
     my $props = $self->__props();
     my ($typeclass, $args) = $props->{tmap}->{$colname} =~ m/^([a-zA-Z0-9_:]+)(?:\(([^\)]+)\))?$/;
-    logtrc 3, "col: %s, type: %s, args: %s", $colname, $typeclass, $args;
+    logtrc 3, "col: %s, type: %s, args: %s", $colname, $typeclass||"undef", $args || "none";
     if ( ref $colvalue eq $typeclass ) {
         $self->{columns}->{$colname} = $colvalue;
     } else {
@@ -91,6 +93,7 @@ sub get {
     unless ( defined $colname ) {
         logcroak "%s->get() usage error", ref($self)
     }
+
     
     my $colvalue = $self->{columns}->{$colname};
 
@@ -107,14 +110,14 @@ sub get {
     }
 
 
-    # if we come this far, this value is being inquiried for the first
+    # if we come this far, this value is being inquired for the first
     # time. So we should load() it. 
     # To do this, we first need to identify its column type, to know how
     # to inflate it.
     my $props                = $self->__props();
     my ($typeclass, $args)    = $props->{tmap}->{ $colname } =~ m/^([a-zA-Z0-9_:]+)(?:\(([^\)]+)\))?$/;
     unless ( $typeclass ) {
-        logcroak "%s->set(): couldn't detect typeclass for this column (%s)", ref($self), $colname
+        logcroak "couldn't detect typeclass for this column (%s)", $colname
     }
 
     # we should cache the loaded object in the column
@@ -409,8 +412,17 @@ sub dump {
 sub __props {
     my $self = shift;
 
-    no strict 'refs';
-    return ${ (ref($self) || $self) . '::props' }
+    my @isa = (ref($self) || $self);
+    while ( my $pkg = shift @isa ) {
+        no strict 'refs';
+        if ( defined (my $props = ${ $pkg . "::props"}) ) {
+            ${ (ref($self) || $self) . "::props" } = $props;
+            return $props;
+        }
+        push @isa, @{ $pkg . "::ISA" };
+    }
+
+    logcroak "couldn't locate properties for this class";
 }
 
 
@@ -452,50 +464,66 @@ sub __driver {
 
 
 
-
-
-
-
 package VARCHAR;
-use Class::PObject::Type::VARCHAR;
 use vars ('@ISA');
+require Class::PObject::Type::VARCHAR;
 @ISA = ("Class::PObject::Type::VARCHAR");
 
 
-
-
 package CHAR;
-use Class::PObject::Type::CHAR;
 use vars ('@ISA');
+require Class::PObject::Type::CHAR;
 @ISA = ("Class::PObject::Type::CHAR");
 
 
-
-
 package INTEGER;
-use Class::PObject::Type::INTEGER;
 use vars ('@ISA');
+require Class::PObject::Type::INTEGER;
 @ISA = ("Class::PObject::Type::INTEGER");
 
 
-
-
 package TEXT;
-use Class::PObject::Type::TEXT;
 use vars ('@ISA');
+require Class::PObject::Type::TEXT;
 @ISA = ("Class::PObject::Type::TEXT");
 
 
 package ENCRYPT;
-use Class::PObject::Type::ENCRYPT;
 use vars ('@ISA');
+require Class::PObject::Type::ENCRYPT;
 @ISA = ("Class::PObject::Type::ENCRYPT");
 
 
 package MD5;
-use Class::PObject::Type::MD5;
 use vars ('@ISA');
+require Class::PObject::Type::MD5;
 @ISA = ("Class::PObject::Type::MD5");
 
 
 1;
+
+__END__;
+
+=pod
+
+=head1 NAME
+
+Class::PObject::Template - Class template for all the pobjects
+
+=head1 DESCRIPTION
+
+Class::PObject::Template defines the structure of all the classes created
+through C<pobject()> construct.
+
+All created pobjects are dynamically set to inherit from Class::PObject::Template.
+
+=head1 NOTES
+
+It would be nice if we had an option of setting an alternative template class
+for pobjects individually.
+
+=head1 AUTHOR and COPYRIGHT
+
+For author and copyright information refer to L<Class::PObject|Class::PObject/>.
+
+=cut
