@@ -1,6 +1,6 @@
 package Class::PObject::Test::HAS_A;
 
-# $Id: HAS_A.pm,v 1.4 2003/09/09 08:46:37 sherzodr Exp $
+# $Id: HAS_A.pm,v 1.5 2003/11/06 01:21:10 sherzodr Exp $
 
 use strict;
 #use diagnostics;
@@ -126,8 +126,8 @@ sub run {
 
     #print $article->dump;
 
-    ok($article->title eq "Class::PObject now supports type-mapping", $article->title);
-    ok($article->author->name eq "Sherzod Ruzmetov",    $article->author->name);
+    ok($article->title eq "Class::PObject now supports type-mapping");
+    ok($article->author->name eq "Sherzod Ruzmetov",    ''.$article->author->name);
     ok(ref($article->author) eq "PO::Author",                ref($article->author));
 
     ok($article->save == $article_id, $article->errstr);
@@ -141,8 +141,8 @@ sub run {
 
     ok($author = $article->author);
     #print $article->dump;
-    ok($article->title eq "Class::PObject now supports type-mapping", $article->title);
-    ok($author->name eq "Sherzod Ruzmetov",    $article->author->name);
+    ok($article->title eq "Class::PObject now supports type-mapping");
+    ok($author->name eq "Sherzod Ruzmetov",    ''.$article->author->name);
     ok(ref($author) eq "PO::Author",                ref($article->author));
 
     #print Dumper($article);
