@@ -1,6 +1,6 @@
 package Class::PObject::Test::Types;
 
-# $Id: Types.pm,v 1.4 2003/09/09 08:46:37 sherzodr Exp $
+# $Id: Types.pm,v 1.6 2004/05/19 06:07:53 sherzodr Exp $
 
 use strict;
 #use diagnostics;
@@ -8,7 +8,7 @@ use Test::More;
 use vars ('$VERSION', '@ISA');
 
 BEGIN {
-    plan(tests => 41);
+    plan(tests => 46);
     use_ok("Class::PObject");
     use_ok("Class::PObject::Test");
     use_ok("Class::PObject::Type");
@@ -56,8 +56,8 @@ sub run {
     #
     ok($u->name             eq "Sherzod Ruzmetov");
     ok($u->login            eq "sherzodr");
-    ok($u->psswd            eq "marley01", $u->psswd);
-    ok($u->activation_key   eq "geek", $u->activation_key);
+    ok($u->psswd            eq "marley01", ''.$u->psswd);
+    ok($u->activation_key   eq "geek", ''.$u->activation_key);
 
     ok(ref($u->name)        eq 'VARCHAR');
     ok(ref($u->login)       eq 'CHAR');
@@ -77,13 +77,13 @@ sub run {
     my $name = VARCHAR->new(id=>"Sherzod Ruzmetov (e)", args=>40);
     ok($name, $name);
     $u->name( $name );
-    ok($u->name            eq "Sherzod Ruzmetov (e)", $u->name);
+    ok($u->name            eq "Sherzod Ruzmetov (e)");
     ok(ref($u->name)    eq "VARCHAR", ref($u->name));
 
     #print $u->dump;
 
     $u->name( "Sherzod Ruzmetov" );
-    ok($u->name            eq "Sherzod Ruzmetov", $u->name);
+    ok($u->name            eq "Sherzod Ruzmetov", ''.$u->name);
     ok(ref($u->name)    eq "VARCHAR", ref($u->name));
 
     #print $u->dump;
@@ -103,7 +103,7 @@ sub run {
     #
     ok($u->name            eq "Sherzod Ruzmetov");
     ok($u->login        eq "sherzodr");
-    ok($u->psswd        eq "marley01", $u->psswd);
+    ok($u->psswd        eq "marley01", ''.$u->psswd);
 
     ok(ref($u->name)    eq 'VARCHAR');
     ok(ref($u->login)    eq 'CHAR');
@@ -117,7 +117,7 @@ sub run {
     $u->name("Sherzod Ruzmetov (e)");
     $u->psswd("marley02)");
 
-    ok($u->psswd        eq "marley02", $u->psswd);
+    ok($u->psswd        eq "marley02", ''.$u->psswd);
     ok($u->name            eq "Sherzod Ruzmetov (e)");
     ok($u->activation_key eq "geek");
     ok(ref($u->psswd)    eq 'ENCRYPT');
@@ -125,6 +125,26 @@ sub run {
     ok($u->save == $id, $u->errstr);
 
 
+	################
+	#
+	# Checking col. member functions (inside Type.pm)
+	#
+	my $substr = $u->name()->substr(0, 6);
+	ok($substr eq "Sherzo", $substr);
+
+    my $lcfirst = $u->name()->lcfirst();
+    ok($lcfirst eq 'sherzod Ruzmetov (e)');
+
+    my $ucfirst = $u->name()->ucfirst();
+    ok($ucfirst eq 'Sherzod Ruzmetov (e)');
+
+    my $lc = $u->name()->lc();
+    ok($lc eq 'sherzod ruzmetov (e)');
+
+    my $uc = $u->name()->uc();
+    ok($uc eq 'SHERZOD RUZMETOV (E)');
+
+
     ################
     #
     # Checking load(\%terms, undef) syntax
